"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Provides a read-only Map interface that aggregates results from multiple results in O(n)
 */
class AggregateMap {
    /**
     * @param maps An Iterable that when iterated provides the Maps to aggregate results from
     */
    constructor(maps) {
        this.maps = maps;
    }
    /**
     * Returns the cumulative size of all Maps
     */
    get size() {
        let size = 0;
        for (const map of this.maps) {
            for (const _ of map) {
                size++;
            }
        }
        return size;
    }
    /**
     * Looks up a key in all Maps and returns the first result
     */
    get(key) {
        for (const map of this.maps) {
            if (map.has(key)) {
                return map.get(key);
            }
        }
        return undefined;
    }
    /**
     * Checks if a key exists in any Map
     */
    has(key) {
        return !!this.get(key);
    }
    /**
     * Iterates over all keys from all Maps
     */
    *keys() {
        for (const map of this.maps) {
            for (const key of map.keys()) {
                yield key;
            }
        }
    }
    /**
     * Iterates over all values from all Maps
     */
    *values() {
        for (const map of this.maps) {
            for (const value of map.values()) {
                yield value;
            }
        }
    }
    /**
     * Iterates over all entries from all Maps
     */
    *entries() {
        for (const map of this.maps) {
            for (const pair of map.entries()) {
                yield pair;
            }
        }
    }
    /**
     * Iterates over all entries from all Maps
     */
    *[Symbol.iterator]() {
        for (const map of this.maps) {
            for (const pair of map) {
                yield pair;
            }
        }
    }
    /**
     * Calls a callback function for all items in all Maps
     */
    forEach(callbackfn, thisArg) {
        for (const [key, value] of this.entries()) {
            callbackfn.call(thisArg, value, key, this);
        }
    }
}
exports.AggregateMap = AggregateMap;
exports.default = AggregateMap;
//# sourceMappingURL=index.js.map